"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing import Union
from typing_extensions import TypedDict


class Data2TypedDict(TypedDict):
    pass


class Data2(BaseModel):
    pass


UpdateDocumentRawParamsDataTypedDict = Union[Data2TypedDict, str]
r"""Document data in a text or JSON format."""


UpdateDocumentRawParamsData = Union[Data2, str]
r"""Document data in a text or JSON format."""


class UpdateDocumentRawParamsTypedDict(TypedDict):
    data: UpdateDocumentRawParamsDataTypedDict
    r"""Document data in a text or JSON format."""


class UpdateDocumentRawParams(BaseModel):
    data: UpdateDocumentRawParamsData
    r"""Document data in a text or JSON format."""
